@@ -1,6 +1,6 @@
 import typing
+
 from typing_extensions import Literal
-from .base_category import BaseCategory
 from vkbottle_types.responses.ads import (
     AddOfficeUsersResponse,
     AdsAccount,
@@ -14,13 +14,13 @@ from vkbottle_types.responses.ads import (
     AdsPromotedPostReach,
     AdsRejectReason,
     AdsStats,
+    AdsTargetGroup,
     AdsTargSettings,
     AdsTargStats,
     AdsTargSuggestions,
     AdsTargSuggestionsCities,
     AdsTargSuggestionsRegions,
     AdsTargSuggestionsSchools,
-    AdsTargetGroup,
     AdsUpdateOfficeUsersResult,
     AdsUsers,
     CheckLinkResponse,
@@ -68,6 +68,8 @@ from vkbottle_types.responses.ads import (
 )
 from vkbottle_types.responses.base import OkResponse
 
+from .base_category import BaseCategory
+
 
 class AdsCategory(BaseCategory):
     async def add_office_users(self, account_id: int, data: str, **kwargs) -> bool:
@@ -603,7 +605,12 @@ class AdsCategory(BaseCategory):
         cities=None,
         lang=None,
         **kwargs
-    ) -> typing.List[AdsTargSuggestions]:
+    ) -> typing.Union[
+        typing.List[AdsTargSuggestions],
+        typing.List[AdsTargSuggestionsRegions],
+        typing.List[AdsTargSuggestionsCities],
+        typing.List[AdsTargSuggestionsSchools],
+    ]:
         """Returns a set of auto-suggestions for various targeting parameters.
 
         :param section: Section, suggestions are retrieved in. Available values: *countries — request of a list of countries. If q is not set or blank, a short list of countries is shown. Otherwise, a full list of countries is shown. *regions — requested list of regions. 'country' parameter is required. *cities — requested list of cities. 'country' parameter is required. *districts — requested list of districts. 'cities' parameter is required. *stations — requested list of subway stations. 'cities' parameter is required. *streets — requested list of streets. 'cities' parameter is required. *schools — requested list of educational organizations. 'cities' parameter is required. *interests — requested list of interests. *positions — requested list of positions (professions). *group_types — requested list of group types. *religions — requested list of religious commitments. *browsers — requested list of browsers and mobile devices.
