@@ -1,6 +1,7 @@
 import typing
+
 from typing_extensions import Literal
-from .base_category import BaseCategory
+from vkbottle_types.responses.base import OkResponse
 from vkbottle_types.responses.board import (
     AddTopicResponse,
     CreateCommentResponse,
@@ -13,7 +14,8 @@ from vkbottle_types.responses.board import (
     GetTopicsResponse,
     GetTopicsResponseModel,
 )
-from vkbottle_types.responses.base import OkResponse
+
+from .base_category import BaseCategory
 
 
 class BoardCategory(BaseCategory):
@@ -197,7 +199,7 @@ class BoardCategory(BaseCategory):
         extended=None,
         sort=None,
         **kwargs
-    ) -> GetCommentsResponseModel:
+    ) -> typing.Union[GetCommentsResponseModel, GetCommentsExtendedResponseModel]:
         """Returns a list of comments on a topic on a community's discussion board.
 
         :param group_id: ID of the community that owns the discussion board.
@@ -260,7 +262,7 @@ class BoardCategory(BaseCategory):
         preview=None,
         preview_length=None,
         **kwargs
-    ) -> GetTopicsResponseModel:
+    ) -> typing.Union[GetTopicsResponseModel, GetTopicsExtendedResponseModel]:
         """Returns a list of topics on a community's discussion board.
 
         :param group_id: ID of the community that owns the discussion board.
