@@ -1,6 +1,7 @@
 import typing
+
 from typing_extensions import Literal
-from .base_category import BaseCategory
+from vkbottle_types.responses.base import BaseBoolInt, BoolResponse, OkResponse
 from vkbottle_types.responses.groups import (
     AddAddressResponse,
     AddCallbackServerResponse,
@@ -71,7 +72,8 @@ from vkbottle_types.responses.groups import (
     SearchResponse,
     SearchResponseModel,
 )
-from vkbottle_types.responses.base import BaseBoolInt, BoolResponse, OkResponse
+
+from .base_category import BaseCategory
 
 
 class GroupsCategory(BaseCategory):
@@ -528,7 +530,7 @@ class GroupsCategory(BaseCategory):
         offset=None,
         count=None,
         **kwargs
-    ) -> GetResponseModel:
+    ) -> typing.Union[GetResponseModel, GetObjectExtendedResponseModel]:
         """Returns a list of the communities to which a user belongs.
 
         :param user_id: User ID.
@@ -698,7 +700,7 @@ class GroupsCategory(BaseCategory):
 
     async def get_catalog_info(
         self, extended=None, subcategories=None, **kwargs
-    ) -> GetCatalogInfoResponseModel:
+    ) -> typing.Union[GetCatalogInfoResponseModel, GetCatalogInfoExtendedResponseModel]:
         """Returns categories list for communities catalog
 
         :param extended: 1 - to return communities count and three communities for preview. By default: 0.
@@ -759,7 +761,7 @@ class GroupsCategory(BaseCategory):
 
     async def get_invites(
         self, offset=None, count=None, extended=None, **kwargs
-    ) -> GetInvitesResponseModel:
+    ) -> typing.Union[GetInvitesResponseModel, GetInvitesExtendedResponseModel]:
         """Returns a list of invitations to join communities and events.
 
         :param offset: Offset needed to return a specific subset of invitations.
@@ -863,7 +865,12 @@ class GroupsCategory(BaseCategory):
         fields=None,
         filter=None,
         **kwargs
-    ) -> GetMembersResponseModel:
+    ) -> typing.Union[
+        GetMembersResponseModel,
+        GetMembersFieldsResponseModel,
+        GetMembersFilterManagersResponseModel,
+        GetMembersFieldsFilterManagersResponseModel,
+    ]:
         """Returns a list of community members.
 
         :param group_id: ID or screen name of the community.
@@ -914,7 +921,7 @@ class GroupsCategory(BaseCategory):
 
     async def get_requests(
         self, group_id=None, offset=None, count=None, fields=None, **kwargs
-    ) -> GetRequestsResponseModel:
+    ) -> typing.Union[GetRequestsResponseModel, GetRequestsFieldsResponseModel]:
         """Returns a list of requests to the community.
 
         :param group_id: Community ID.
@@ -1033,7 +1040,12 @@ class GroupsCategory(BaseCategory):
 
     async def is_member(
         self, group_id=None, user_id=None, user_ids=None, extended=None, **kwargs
-    ) -> BaseBoolInt:
+    ) -> typing.Union[
+        BaseBoolInt,
+        typing.List[GroupsMemberStatus],
+        IsMemberExtendedResponseModel,
+        typing.List[GroupsMemberStatusFull],
+    ]:
         """Returns information specifying whether a user is a member of a community.
 
         :param group_id: ID or screen name of the community.
