@@ -1,6 +1,12 @@
 import typing
+
 from typing_extensions import Literal
-from .base_category import BaseCategory
+from vkbottle_types.responses.base import (
+    BaseBoolInt,
+    BaseGetUploadServerResponse,
+    BaseUploadServer,
+    OkResponse,
+)
 from vkbottle_types.responses.polls import (
     AddVoteResponse,
     CreateResponse,
@@ -13,12 +19,8 @@ from vkbottle_types.responses.polls import (
     PollsVoters,
     SavePhotoResponse,
 )
-from vkbottle_types.responses.base import (
-    BaseBoolInt,
-    BaseUploadServer,
-    GetUploadServerResponse,
-    OkResponse,
-)
+
+from .base_category import BaseCategory
 
 
 class PollsCategory(BaseCategory):
@@ -173,7 +175,7 @@ class PollsCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("polls.getPhotoUploadServer", params)
-        model = GetUploadServerResponse
+        model = BaseGetUploadServerResponse
         return model(**response).response
 
     async def get_voters(
