@@ -1,10 +1,11 @@
 import inspect
 import typing
+
 from .base_response import BaseResponse
 
 
 class RestoreResponse(BaseResponse):
-    response: "RestoreResponseModel" = None
+    response: "RestoreResponseModel"
 
 
 class RestoreResponseModel(BaseResponse):
