@@ -1,18 +1,20 @@
 import inspect
-from .base_response import BaseResponse
+
 from vkbottle_types.objects import BaseBoolInt, BaseUploadServer
 
+from .base_response import BaseResponse
+
 
 class BoolResponse(BaseResponse):
-    response: BaseBoolInt = None
-
-
-class GetUploadServerResponse(BaseResponse):
-    response: BaseUploadServer = None
+    response: BaseBoolInt
 
 
 class OkResponse(BaseResponse):
-    response: int = None
+    response: int
+
+
+class BaseGetUploadServerResponse(BaseResponse):
+    response: BaseUploadServer
 
 
 for item in locals().copy().values():
