@@ -1,10 +1,11 @@
 import inspect
 import typing
+
 from .base_response import BaseResponse
 
 
 class PaidStatusResponse(BaseResponse):
-    response: "PaidStatusResponseModel" = None
+    response: "PaidStatusResponseModel"
 
 
 class PaidStatusResponseModel(BaseResponse):
