@@ -1,11 +1,13 @@
 import inspect
 import typing
-from .base_response import BaseResponse
+
 from vkbottle_types.objects import GiftsGift
 
+from .base_response import BaseResponse
+
 
 class GetResponse(BaseResponse):
-    response: "GetResponseModel" = None
+    response: "GetResponseModel"
 
 
 class GetResponseModel(BaseResponse):
