@@ -1,11 +1,13 @@
 import inspect
 import typing
-from .base_response import BaseResponse
+
 from vkbottle_types.objects import PodcastExternalData
 
+from .base_response import BaseResponse
+
 
 class SearchPodcastResponse(BaseResponse):
-    response: "SearchPodcastResponseModel" = None
+    response: "SearchPodcastResponseModel"
 
 
 class SearchPodcastResponseModel(BaseResponse):
