@@ -1,10 +1,11 @@
 import inspect
 import typing
+
 from .base_response import BaseResponse
 
 
 class GetServerUrlResponse(BaseResponse):
-    response: "GetServerUrlResponseModel" = None
+    response: "GetServerUrlResponseModel"
 
 
 class GetServerUrlResponseModel(BaseResponse):
